<?php

namespace Projectify;

// Exit if accessed directly. 
if ( ! defined( 'ABSPATH' ) ) { exit; }


// Helper Class
class Projectify_Helper
{
	
	public static function projectify_open_wrap(){
		return '<div class="projectify_wrapper">';
	}
	public static function projectify_close_wrap(){
		return '</div>';
	}
	
	// since v2.1
	// added on 19.05.2021
	public static function projectify_all_terms($post_type){
		$result = [];
		if( $post_type !== 'page' && $post_type !== '' ){
			$taxonomys 	= get_object_taxonomies( $post_type );
			$exclude 	= array( 'post_tag', 'post_format' );
			if($taxonomys != ''){
				foreach($taxonomys as $taxonomy){
					if( in_array( $taxonomy, $exclude ) ) { continue; }
					$terms = get_terms($taxonomy, array('hide_empty' => true, 'orderby' => 'name'));
					foreach ( $terms as $term ) {
						$result[$term->slug."______".$taxonomy] = "{" .$taxonomy. "} " . ucfirst($term->name);
					}
				}
			}
		}
		return $result;
	}
	public static function projectify_all_posts($post_type){
		$query_args = array(
			'post_type' 			=> $post_type,
			'posts_per_page' 		=> -1,
			'post_status' 			=> 'publish',
		);
		
		$loop 			= new \WP_Query($query_args);
		
		$array = array();

		foreach ( $loop->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id 			= $fn_post->ID;
			$post_title			= $fn_post->post_title;
			$array[$post_id] 	= 'ID: ' . $post_id . '; ' . $post_title . '.';
			wp_reset_postdata();
		}
		return $array;
	}
	
	
    // Get Post Types
    public static function post_types()
    {
		$selectedPostTypes = [];
		$args = array('public' => true);
		
		// includes
		foreach ( get_post_types( $args, 'names' ) as $post_type ) 
		{
			$title = str_replace( '-', ' ', $post_type );
			$title = ucwords( str_replace( '_', ' ', $title ) );
			
			$selectedPostTypes[$post_type] = $title;
		}
		
		// excludes
		unset($selectedPostTypes['attachment']);
		unset($selectedPostTypes['elementor_library']);
		
		return $selectedPostTypes;
		
    }
	
	public static function post_terms_beta($post_type)
	{	
		$selectedPostTerms = [];

		// post cats
		if( $post_type == 'post' )
		{
			$terms = get_categories();
			foreach ( $terms as $term ) 
			{
				$selectedPostTerms[$term->slug] = $term->name;
			}
		}
		else if( $post_type == 'page' )
		{
			// do nothing
		}
		else if( $post_type != '' )
		{
			$taxonomys = get_object_taxonomies( $post_type );
			$exclude = array( 'post_tag', 'post_format' );

			if($taxonomys != '')
			{
				foreach($taxonomys as $taxonomy)
				{
					// exclude post tags
					if( in_array( $taxonomy, $exclude ) ) { continue; }

					$terms = get_terms($taxonomy, array('hide_empty' => true));
					foreach ( $terms as $term ) 
					{
						$selectedPostTerms[$term->slug] = $term->name;
					}
				}
			}
		}
		else
		{

		}

		// custom post cats
		return $selectedPostTerms;
	}
	
	
	
	
	public static function post_taxanomy($post_type)
	{	
		$selectedPostTaxonomies = [];
		
		if( $post_type == 'page' )
		{
			
		}
		else if( $post_type != '' )
		{
			$taxonomys 	= get_object_taxonomies( $post_type );
			$exclude 	= array( 'post_tag', 'post_format' );

			if($taxonomys != '')
			{
				foreach($taxonomys as $key => $taxonomy)
				{
					// exclude post tags
					if( in_array( $taxonomy, $exclude ) ) { continue; }

					$selectedPostTaxonomies[$key] = $taxonomy;
				}
			}
		}
		else
		{

		}
		
		// since v2.4
		if($post_type == 'product'){
			if(in_array('product_cat',$selectedPostTaxonomies)){
				$selectedPostTaxonomies = ['product_cat'];
			}
		}
		// custom post cats
		return $selectedPostTaxonomies;
	}
	
	
	
	
	// POST TERMS
	public static function post_term_list($postid, $taxanomy, $echo = true, $max = 2, $seporator = ' , '){
		
		$terms = $termlist = $term_link = $cat_count = '';
		$terms = get_the_terms($postid, $taxanomy);

		if($terms != ''){

			$cat_count = sizeof($terms);
			if($cat_count >= $max){$cat_count = $max;}
			
			for($i = 0; $i < $cat_count; $i++){
				$term_link = get_term_link( $terms[$i]->slug, $taxanomy );
				$termlist .= '<a href="'.$term_link.'"><span class="extra"></span>'.$terms[$i]->name.'</a>'.$seporator;
			}
			$termlist = trim($termlist, $seporator);
		}

		if($echo == true){
			echo wp_kses_post($termlist);
		}else{
			return wp_kses_post($termlist);
		}
	}
	
	public static function post_term_list_second($postid, $taxanomy){
		
		$terms = $termlist = $term_link = $cat_count = '';
		$terms = get_the_terms($postid, $taxanomy);

		if($terms != ''){

			$cat_count = sizeof($terms);

			for($i = 0; $i < $cat_count; $i++){
				$term_link = get_term_link( $terms[$i]->slug, $taxanomy );
				$termlist .= $terms[$i]->name.' ';
			}
			$termlist = trim($termlist, ' ');
		}
		return wp_kses_post($termlist);
	}
	


	
}
