<?php
namespace Projectify\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Projectify\Projectify_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Projectify Site Title
 */
class Projectify_All_Widgets extends Widget_Base {

	public function get_name() {
		return 'projectify-all-widgets';
	}

	public function get_title() {
		return __( 'Projectify Widgets', 'projectify' );
	}

	public function get_icon() {
		return 'eicon-image-rollover';
	}

	public function get_categories() {
		return [ 'projectify-elements' ];
	}

	protected function register_controls() {
		
		

		$this->start_controls_section(
			'all_filter',
			[
				'label' => __( 'Filter', 'projectify' ),
			]
		);
		
		
		$this->add_control(
            'fn_widget_layout',
            [
                'label' => esc_html__( 'Layout', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'carousel_circle' 	=> esc_html__( 'Carousel Circle', 'projectify' ),
                    'carousel_full_a' 	=> esc_html__( 'Carousel Full Alpha', 'projectify' ),
                    'carousel_full_b' 	=> esc_html__( 'Carousel Full Beta', 'projectify' ),
                    'carousel_full_i' 	=> esc_html__( 'Carousel Full Interactive', 'projectify' ),
                    'carousel_square' 	=> esc_html__( 'Carousel Square', 'projectify' ),
                    'carousel_with_c' 	=> esc_html__( 'Carousel With Content', 'projectify' ),
                    'list_just' 		=> esc_html__( 'List Justified', 'projectify' ),
                    'list_masonry' 		=> esc_html__( 'List Masonry', 'projectify' ),
                    'slider_a' 			=> esc_html__( 'Slider Alpha', 'projectify' ),
                    'slider_b' 			=> esc_html__( 'Slider Beta', 'projectify' ),
                    'slider_d' 			=> esc_html__( 'Slider Delta', 'projectify' ),
                    'slider_e' 			=> esc_html__( 'Slider Epsilon', 'projectify' ),
                    'slider_g' 			=> esc_html__( 'Slider Gamma', 'projectify' ),
                    'slider_z' 			=> esc_html__( 'Slider Zeta', 'projectify' ),
                ],
                'default' => 'carousel_circle',

            ]
        );
		$this->add_control(
			'fn_post_types',
			[
				'label'     => __( 'Post Types', 'projectify' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'post',
				'options' 	=> Projectify_Helper::post_types(),
				'selectors' => [ // You can use the selected value in an auto-generated css rule.
				
				],
			]
		);
		
		foreach(Projectify_Helper::post_types() as $key => $item){
			$this->add_control(
				$key.'_terms',
				[
					 'label' 		=> $item. __( ' Taxonomies', 'projectify' ),
					 'type' 		=> Controls_Manager::SELECT2,
					 'multiple' 	=> true,
					 'options' 		=> Projectify_Helper::projectify_all_terms($key),
					 'condition'	=> ['fn_post_types' => $key],
					 'label_block'	=> true
				]
			);
		}
		foreach(Projectify_Helper::post_types() as $key => $item){
			$this->add_control(
				$key.'_included_posts',
				[
					 'label' 		=> $item. __( ' Include', 'projectify' ),
					 'type' 		=> Controls_Manager::SELECT2,
					 'multiple' 	=> true,
					 'options' 		=> Projectify_Helper::projectify_all_posts($key),
					 'condition'	=> ['fn_post_types' => $key],
					 'label_block'	=> true
				]
			);
		}
		
		$this->add_control(
			'fn_post_number',
			[
				'label' => __( 'Posts Number', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 9,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 9999,
						'step' => 1,
					]
				],
			]
		);
		
		$this->add_control(
            'fn_post_offset',
            [
                'label' => esc_html__( 'Post Offset', 'projectify' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '0'
            ]
        );
		
		$this->add_control(
            'fn_post_order',
            [
                'label' => esc_html__( 'Post Order', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'projectify' ),
                    'desc' 	=> esc_html__( 'Descending', 'projectify' )
                ],
                'default' => 'desc',

            ]
        );
		
		$this->add_control(
            'fn_post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', 'projectify' ),
                    'ID' 				=> esc_html__( 'By ID', 'projectify' ),
                    'author' 			=> esc_html__( 'By Author', 'projectify' ),
                    'title' 			=> esc_html__( 'By Title', 'projectify' ),
                    'name' 				=> esc_html__( 'By Name', 'projectify' ),
                    'rand' 				=> esc_html__( 'Random', 'projectify' ),
                    'comment_count' 	=> esc_html__( 'By Number of Comments', 'projectify' ),
                    'menu_order' 		=> esc_html__( 'By Page Order', 'projectify' ),
                ],
                'default' => 'select',

            ]
        );
		// since 04.08.2018
		$this->add_control(
            'fn_page_include',
            [
                'label' => esc_html__( 'Display Pages', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'all_pages' 		=> esc_html__( 'All Pages', 'projectify' ),
                    'featured_pages'	=> esc_html__( 'Featured Pages', 'projectify' ),
                ],
                'default' => 'all_pages',
				'condition' => [
									'fn_post_types' => 'page'
								]
            ]
        );
		

		$this->end_controls_section();
		
		
		/************************************************************************/
		/************************* CAROUSEL CIRCLE *****************************/
		/**********************************************************************/
		
		$this->start_controls_section(
			'carousel_circle_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('carousel_circle')
								]
			]
		);
		$this->add_control(
			'cc_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'cc_main_layout',
            [
                'label' => esc_html__( 'Layout', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'alpha' 			=> esc_html__( 'Alpha', 'projectify' ),
                    'beta' 				=> esc_html__( 'Beta', 'projectify' ),
                    'gamma' 			=> esc_html__( 'Gamma', 'projectify' ),
                    'numbered' 			=> esc_html__( 'Numbered', 'projectify' ),
                    'numbered2' 		=> esc_html__( 'Numbered 2', 'projectify' ),
                ],
                'default' => 'alpha',

            ]
        );
		
		$this->add_control(
			'cc_numbered_img_thumb',
			[
				'label' => __( 'Image Thumb', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cc_main_layout' => array('numbered', 'numbered2')
								]
			]
		);
		
		$this->add_control(
			'cc_numbered_hover_thumb',
			[
				'label' => __( 'Hover Thumb', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cc_main_layout' => array('numbered', 'numbered2')
								]
			]
		);
		
		$this->add_control(
            'cc_beta_bg_line',
            [
                'label' => esc_html__( 'Background Line', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'gradient' 			=> esc_html__( 'Gradient Overlay', 'projectify' ),
                    'color' 			=> esc_html__( 'Color Overlay', 'projectify' ),
                ],
                'default' => 'gradient',
				'condition' => [
								'cc_main_layout' => 'beta'
								]

            ]
        );
		
		$this->add_control(
			'cc_box_shadow_gamma',
			[
				'label' => __( 'Box Shadow for Active Item', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cc_main_layout' => 'gamma'
								]
			]
		);
		
		$this->add_control(
			'cc_box_shadow_numbered',
			[
				'label' => __( 'Box Shadow Item on hover', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cc_main_layout' => 'numbered'
								]
			]
		);
		$this->add_control(
			'cc_box_shadow_numbered2',
			[
				'label' => __( 'Box Shadow Item on hover', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cc_main_layout' => 'numbered2'
								]
			]
		);
		
		$this->add_control(
			'cc_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_circle .gamma_controller span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_circle .gamma_controller span.b' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
				'condition' => [
								'cc_main_layout' => 'gamma',
								]
			]
		);
		$this->add_control(
			'cc_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_circle .gamma_controller div' => 'background-color: {{VALUE}};',
				],
				'default' => '#fb3183',
				'condition' => [
								'cc_main_layout' => 'gamma',
								]
			]
		);
		$this->add_control(
			'cc_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'cc_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cc_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_circle .title_holder p',
				'condition' => [
								'cc_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cc_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_circle .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_circle .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_circle .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cc_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cc_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cc_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_circle .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'cc_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_circle .title_holder h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_circle .title_holder h3' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'cc_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_circle .title_holder h3 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_circle .title_holder h3:hover' => 'color: {{VALUE}};',
				],
				'default' => '#ccc',
			]
		);
		
		
		$this->end_controls_section();
		
		/************************************************************************/
		/*********************** CAROUSEL FULL ALPHA ***************************/
		/**********************************************************************/
		
		$this->start_controls_section(
			'carousel_full_alpha_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('carousel_full_a')
								]
			]
		);
		$this->add_control(
			'cfa_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'cfa_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'cfa_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['cfa_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
			'cfa_columns_number',
			[
				'label' => __( 'Columns Number', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 4,
				],
				'range' => [
					'px' => [
						'min' => 2,
						'max' => 5,
						'step' => 1,
					]
				],
				'size_units' => [''],
			]
		);
		$this->add_control(
            'cfa_title_holder_type',
            [
                'label' => esc_html__( 'Title Holder Type', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                    'dynamic' 			=> esc_html__( 'Dynamic', 'projectify' ),
                    'smooth' 			=> esc_html__( 'Smooth', 'projectify' ),
                ],
                'default' => 'static',

            ]
        );
		$this->add_control(
			'cfa_separator_color',
			[
				'label' => __( 'Separator Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl-carousel .item:after' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(255,255,255,0)',
			]
		);
		
		$this->add_control(
            'cfa_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		
		$this->add_control(
			'cfa_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_carousel_full_alpha[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_carousel_full_alpha[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_carousel_full_alpha[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cfa_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.1)',
			]
		);
		$this->add_control(
			'cfa_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'cfa_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfa_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder p',
				'condition' => [
								'cfa_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cfa_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cfa_category_show' => 'yes'
								],
				'default' => '#eee',
			]
		);
		$this->add_control(
			'cfa_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfa_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'cfa_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#eee',
			]
		);
		
		$this->add_control(
			'cfa_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .item .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cfa_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'cfa_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'extendable',

            ]
        );
		$this->add_control(
			'cfa_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl-carousel .item .title_holder > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl-carousel .item .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl-carousel .item .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_alpha .owl-carousel .item .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cfa_read_more_types!' => 'none',
								],
				'default' => '#fff',
			]
		);
		
		
		$this->end_controls_section();
		
		/************************************************************************/
		/************************ CAROUSEL FULL BETA ***************************/
		/**********************************************************************/
		
		$this->start_controls_section(
			'carousel_full_beta_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('carousel_full_b')
								]
			]
		);
		$this->add_control(
			'cfb_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'cfb_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'cfb_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['cfb_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
			'cfb_columns_number',
			[
				'label' => __( 'Columns Number', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 4,
				],
				'range' => [
					'px' => [
						'min' => 2,
						'max' => 5,
						'step' => 1,
					]
				],
				'size_units' => [''],
			]
		);
		$this->add_control(
            'cfb_title_holder_type',
            [
                'label' => esc_html__( 'Title Holder Type', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                    'dynamic' 			=> esc_html__( 'Dynamic', 'projectify' ),
                ],
                'default' => 'static',
				'condition' => [
									'cfb_title_holder_position!' => 'middle'
								]
            ]
        );
		
		$this->add_control(
            'cfb_title_holder_position',
            [
                'label' => esc_html__( 'Title Holder Position', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'top' 				=> esc_html__( 'Top', 'projectify' ),
                    'middle' 			=> esc_html__( 'Middle', 'projectify' ),
                    'bottom' 			=> esc_html__( 'Bottom', 'projectify' ),
                ],
                'default' => 'bottom',

            ]
        );
		$this->add_control(
            'cfb_title_holder_alignment',
            [
                'label' => esc_html__( 'Title Holder Alignment', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'left' 				=> esc_html__( 'Left Align', 'projectify' ),
                    'center' 			=> esc_html__( 'Center Align', 'projectify' ),
                    'right' 			=> esc_html__( 'Right Align', 'projectify' ),
                ],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder' => 'text-align: {{VALUE}};',
				],
                'default' => 'center',
            ]
        );
		
		$this->add_control(
			'cfb_title_holder_bg',
			[
				'label' => __( 'Title Holder Background', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'cfb_separator_color',
			[
				'label' => __( 'Separator Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item:after' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,0.5)',
			]
		);
		
		$this->add_control(
            'cfb_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		
		$this->add_control(
			'cfb_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_carousel_full_beta[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_carousel_full_beta[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_carousel_full_beta[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'cfb_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.1)',
			]
		);
		$this->add_control(
			'cfb_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'cfb_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfb_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_full_beta .item .title_holder p',
				'condition' => [
								'cfb_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cfb_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cfb_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cfb_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfb_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'cfb_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder h3 a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'cfb_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_beta .owl-carousel .item .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		/************************************************************************/
		/********************* CAROUSEL FULL INTERACTIVE ***********************/
		/**********************************************************************/
		
		$this->start_controls_section(
			'carousel_full_interactive_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('carousel_full_i')
								]
			]
		);
		$this->add_control(
			'cfi_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'cfi_columns_number',
			[
				'label' => __( 'Columns Number', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 4,
				],
				'range' => [
					'px' => [
						'min' => 2,
						'max' => 5,
						'step' => 1,
					]
				],
				'size_units' => [''],
			]
		);
		$this->add_control(
            'cfi_title_holder_type',
            [
                'label' => esc_html__( 'Title Holder Type', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                    'dynamic' 			=> esc_html__( 'Dynamic', 'projectify' ),
                    'smooth' 			=> esc_html__( 'Smooth', 'projectify' ),
                ],
                'default' => 'static',

            ]
        );
		$this->add_control(
			'cfi_separator_color',
			[
				'label' => __( 'Separator Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl-carousel .item:after' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
            'cfi_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',
            ]
        );
		
		$this->add_control(
			'cfi_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_carousel_full_interactive[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_carousel_full_interactive[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_carousel_full_interactive[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cfi_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.1)',
			]
		);
		$this->add_control(
			'cfi_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'cfi_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfi_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder p',
				'condition' => [
								'cfi_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cfi_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cfi_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cfi_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfi_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'cfi_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder h3 a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'cfi_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .item .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'cfi_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'cfi_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'extendable',

            ]
        );
		$this->add_control(
			'cfi_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl-carousel .item .title_holder > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl-carousel .item .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl-carousel .item .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl-carousel .item .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_full_interactive .owl-carousel .item .title_holder > span a.read_more' => 'color: {{VALUE}};',
				],
				'condition' => [
								'cfi_read_more_types!' => 'none',
								],
				'default' => '#fff',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/*************************** CAROUSEL SQUARE ***************************/
		/**********************************************************************/
		$this->start_controls_section(
			'carousel_square_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('carousel_square')
								]
			]
		);
		
		$this->add_control(
			'cs_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'cs_main_layout',
            [
                'label' => esc_html__( 'Layout', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'alpha' 			=> esc_html__( 'Alpha', 'projectify' ),
                    'beta' 				=> esc_html__( 'Beta', 'projectify' ),
                    'gamma' 			=> esc_html__( 'Gamma', 'projectify' ),
                    'mini' 				=> esc_html__( 'Mini', 'projectify' ),
                    'numbered' 			=> esc_html__( 'Numbered', 'projectify' ),
                ],
                'default' => 'alpha',

            ]
        );
		
		$this->add_control(
            'cs_item_ratio',
            [
                'label' => esc_html__( 'Item Ratio', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'landscape' 			=> esc_html__( 'Landscape', 'projectify' ),
                    'portrait' 				=> esc_html__( 'Portrait', 'projectify' ),
                    'square' 				=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'portrait',

            ]
        );
		
		$this->add_control(
			'cs_box_shadow_alpha',
			[
				'label' => __( 'Box Shadow for Active Item', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cs_main_layout' => 'alpha'
								]
			]
		);
		
		$this->add_control(
			'cs_box_shadow_beta',
			[
				'label' => __( 'Box Shadow Item on hover', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
				'condition' => [
								'cs_main_layout' => 'beta'
								]
			]
		);
		$this->add_control(
			'cs_title_bg_color_gamma',
			[
				'label' => __( 'Title Holder Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_square.gamma .title_holder' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(10,44,174,.5)',
				'condition' => [
								'cs_main_layout' => 'gamma'
								]
			]
		);
		
		$this->add_control(
            'cs_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		
		$this->add_control(
			'cs_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_square .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_carousel_square[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_carousel_square[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_carousel_square[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_carousel_square.numbered .numbered_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square.numbered .numbered_control span.b' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cs_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_square .owl_control > div' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square.numbered .n_prev:after' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square.numbered .n_prev > span:after, {{WRAPPER}} .projectify_carousel_square.numbered .n_next > span:after' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.1)',
			]
		);
		$this->add_control(
			'cs_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'cs_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cs_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_square .item .title_holder p',
				'condition' => [
								'cs_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cs_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_square .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_square .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cs_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cs_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cs_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_square .item .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'cs_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_square .item .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'cs_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_square .item .title_holder h3 a:hover' => 'color: {{VALUE}};',
				],
				'default' => '#000',
			]

		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/************************ CAROUSEL WITH CONTENT ************************/
		/**********************************************************************/
		$this->start_controls_section(
			'carousel_with_content_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('carousel_with_c')
								]
			]
		);
		
		$this->add_control(
			'cwc_content_part',
			[
				'label' => __( 'Content Part', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'after',
			]
		);
		
		$this->add_control(
		  'cwc_fslide_title',
		  [
			 'label'       => __( 'Title', 'projectify' ),
			 'type'        => Controls_Manager::TEXT,
			 'placeholder' => __( 'Type your title text here', 'projectify' ),
		  ]
		);
		
		$this->add_control(
			'cwc_fslide_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_with_content .description h3' => 'color: {{VALUE}};',
				],
				'default' => '#ccc',
			]
		);
		
		$this->add_control(
		  'cwc_fslide_desc',
		  [
			 'label'   => __( 'Description', 'projectify' ),
			 'type'    => Controls_Manager::TEXTAREA,
			 'placeholder' => __( 'Type your description text here', 'projectify' ),
		  ]
		);
		
		$this->add_control(
			'cwc_fslide_desc_color',
			[
				'label' => __( 'Description Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_with_content .description p' => 'color: {{VALUE}};',
				],
				'default' => '#999',
			]
		);
		
		$this->add_control(
		  'cwc_fslide_sign',
		  [
			 'label' => __( 'Choose Your Sign', 'projectify' ),
			 'type' => Controls_Manager::MEDIA,
			 'default' => [
				'url' => Utils::get_placeholder_image_src(),
			 ],
		  ]
		);
		
		$this->add_control(
			'cwc_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'cwc_main_layout',
            [
                'label' => esc_html__( 'Layout', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'alpha' 			=> esc_html__( 'Alpha', 'projectify' ),
                    'beta' 				=> esc_html__( 'Beta', 'projectify' ),
                ],
                'default' => 'alpha',

            ]
        );
		
		$this->add_control(
            'cwc_img_ratio',
            [
                'label' => esc_html__( 'Image Ratio', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'landscape' 		=> esc_html__( 'Landscape', 'projectify' ),
                    'portrait' 			=> esc_html__( 'Portrait', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'square',

            ]
        );
		
		$this->add_control(
            'cwc_alpha_bg_type',
            [
                'label' => esc_html__( 'Title Background Overlay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'no_o' 				=> esc_html__( 'No Overlay', 'projectify' ),
                    'color_o' 			=> esc_html__( 'Color Overlay', 'projectify' ),
                    'gradient_o'		=> esc_html__( 'Gradient Overlay', 'projectify' ),
                ],
                'default' => 'color_o',
				'condition' => [
								'cwc_main_layout' => 'alpha'
								],
            ]
        );
		
		$this->add_control(
			'cwc_alpha_bg_color',
			[
				'label' => __( 'Title Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .alpha .fn-sample-slides .title_holder' => 'background-color: {{VALUE}};',
				],
				'condition' => [
								'cwc_alpha_bg_type' => 'color_o'
								],
				'default' => 'rgba(0,0,0,0.4)',
			]
		);
		
		$this->add_control(
			'cwc_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'cwc_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cwc_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_with_content .title_holder p',
				'condition' => [
								'cwc_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'cwc_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder p a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'cwc_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'cwc_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cwc_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_carousel_with_content .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'cwc_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder h3:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'cwc_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder h3 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .title_holder h3:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_carousel_with_content .beta_title_holder h3:hover:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#ccc',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/*************************** LIST JUSTIFIED ****************************/
		/**********************************************************************/
		$this->start_controls_section(
			'list_justified_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('list_just')
								]
			]
		);
		
		$this->add_control(
			'lj_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'lj_img_height',
			[
				'label' => __( 'Image Height (px)', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 300,
				],
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 700,
						'step' => 5,
					]
				],
				'size_units' => [''],
			]
		);
		
		$this->add_control(
			'lj_img_gutter',
			[
				'label' => __( 'Image Gutter (px)', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 10,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 40,
						'step' => 1,
					]
				],
				'size_units' => [''],
			]
		);
		$this->add_control(
			'lj_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'lj_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lj_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_justified_images .caption p',
				'condition' => [
								'lj_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'lj_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_justified_images .caption p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_justified_images .caption p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'lj_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'lj_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lj_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_justified_images .caption h3 a',
			]
		);
		
		$this->add_control(
			'lj_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_justified_images .caption h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_justified_images .caption h3' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'lj_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_justified_images .caption h3 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_justified_images .caption h3:hover' => 'color: {{VALUE}};',
				],
				'default' => '#eee',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/**************************** LIST MASONRY *****************************/
		/**********************************************************************/
		
		$this->start_controls_section(
			'list_masonry_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('list_masonry')
								]
			]
		);
		
		$this->add_control(
			'lm_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'lm_main_layout',
            [
                'label' => esc_html__( 'Layout', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'masonry' 			=> esc_html__( 'Masonry', 'projectify' ),
                    'grid' 				=> esc_html__( 'Grid', 'projectify' ),
                ],
                'default' => 'masonry',

            ]
        );
		
		$this->add_control(
            'lm_grid_ratio',
            [
                'label' => esc_html__( 'Grid Ratio', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'landscape' 			=> esc_html__( 'Landscape', 'projectify' ),
                    'portrait' 				=> esc_html__( 'Portrait', 'projectify' ),
                    'square' 				=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'square',
				'condition' => [
									'lm_main_layout' => 'grid'
								]
            ]
        );
		
		$this->add_control(
            'lm_title_holder_pos',
            [
                'label' => esc_html__( 'Title Holder Position', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'inside' 			=> esc_html__( 'Inside', 'projectify' ),
                    'outside' 			=> esc_html__( 'Outside', 'projectify' ),
                    'hover' 			=> esc_html__( 'On Hover', 'projectify' ),
                ],
                'default' => 'outside',
            ]
        );
		
		$this->add_control(
            'lm_title_holder_bg',
            [
                'label' => esc_html__( 'Title Holder Background', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'no_o' 					=> esc_html__( 'No Overlay', 'projectify' ),
                    'color_o' 				=> esc_html__( 'Color Overlay', 'projectify' ),
                    'gradient_o' 			=> esc_html__( 'Gradient Overlay', 'projectify' ),
                ],
                'default' => 'color_o',
				'condition' => [
									'lm_title_holder_pos' => 'inside'
								]
            ]
        );
		
		$this->add_control(
			'lm_title_holder_bgcolor',
			[
				'label' => __( 'Title Holder Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap[data-title-holder-pos="inside"][data-title-holder-bg="color_o"] .title_holder' => 'background-color: {{VALUE}};',
				],
				'condition' => [
								'lm_title_holder_bg' => 'color_o',
								],
				'default' => '#333',
			]
		);
		$this->add_control(
			'lm_title_holder_bghovercolor',
			[
				'label' => __( 'Title Holder Background Color on Hover', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap[data-title-holder-pos="hover"] .title_holder' => 'background-color: {{VALUE}};',
				],
				'condition' => [
								'lm_title_holder_pos' => 'hover',
								],
				'default' => 'rgba(0,0,0,0.9)',
			]
		);
		
		$this->add_control(
            'lm_title_holder_animation',
            [
                'label' => esc_html__( 'Title Holder Animation', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'full' 					=> esc_html__( 'Full Overlay', 'projectify' ),
                    'boxed' 				=> esc_html__( 'Boxed Overlay', 'projectify' ),
                ],
                'default' => 'full',
				'condition' => [
									'lm_title_holder_pos' => 'hover'
								]
            ]
        );
		
		$this->add_control(
			'lm_cols_number',
			[
				'label' => __( 'Columns Number', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 3,
				],
				'range' => [
					'px' => [
						'min' => 2,
						'max' => 6,
						'step' => 1,
					]
				],
				'size_units' => [''],
				'selectors' => [
					'{{WRAPPER}} .box' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'lm_cols_gutter',
			[
				'label' => __( 'Columns Gutter (px)', 'projectify' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 10,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 40,
						'step' => 1,
					]
				],
				'size_units' => [''],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap ul.projectify_list li' => 'padding-left: {{SIZE}}{{UNIT}};margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .projectify_all_list_wrap ul.projectify_list' => 'margin-left: -{{SIZE}}{{UNIT}};',
				],
			]
		);
		
		
		$this->add_control(
			'lm_term_filter',
			[
				'label' => __( 'Filter By Category', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes', 
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lm_typography_4',
				'label' => __( 'Filter Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_all_list_wrap ul.projectify_filter li a',
				'condition' => [
								'lm_term_filter' => 'yes'
								]
			]
		);
		$this->add_control(
			'lm_filter_color',
			[
				'label' => __( 'Filter Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap ul.projectify_filter li a' => 'color: {{VALUE}};',
				],
				'condition' => [
								'lm_term_filter' => 'yes'
								],
				'default' => '#777',
			]
		);
		$this->add_control(
			'lm_filter_hover_color',
			[
				'label' => __( 'On Hover and Selected Filter Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap ul.projectify_filter li a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_all_list_wrap ul.projectify_filter li a.current' => 'color: {{VALUE}};',
				],
				'condition' => [
								'lm_term_filter' => 'yes'
								],
				'default' => '#000',
			]
		);
		$this->add_control(
			'lm_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'lm_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lm_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_all_list_wrap .title_holder p',
				'condition' => [
								'lm_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'lm_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_all_list_wrap .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'lm_category_show' => 'yes'
								],
				'default' => '#333',
			]
		);
		$this->add_control(
			'lm_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lm_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_all_list_wrap .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'lm_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap .title_holder h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_all_list_wrap .title_holder h3' => 'color: {{VALUE}};',
				],
				'default' => '#333',
			]
		);
		
		$this->add_control(
			'lm_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_all_list_wrap .title_holder h3 a:hover,{{WRAPPER}} .projectify_all_list_wrap .title_holder h3:hover,{{WRAPPER}} .projectify_all_list_wrap .item:hover .title_holder h3 a,{{WRAPPER}} .projectify_all_list_wrap .item:hover .title_holder h3' => 'color: {{VALUE}};',
				],
				'default' => '#000',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/*************************** SLIDER ALPHA ******************************/
		/**********************************************************************/
		$this->start_controls_section(
			'slider_alpha_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('slider_a')
								]
			]
		);
		
		
		$this->add_control(
			'sa_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'sa_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'sa_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['sa_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
			'sa_title_bgcolor',
			[
				'label' => __( 'Title Holder Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .title_holder' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(14,14,14,0.9)',
			]
		);
		$this->add_control(
            'sa_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'square',

            ]
        );
		
		$this->add_control(
			'sa_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_slider_alpha[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_slider_alpha[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_slider_alpha[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sa_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => '#d91a46',
			]
		);
		$this->add_control(
			'sa_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'sa_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sa_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_alpha .item .title_holder p',
				'condition' => [
								'sa_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'sa_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sa_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sa_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sa_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_alpha .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'sa_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sa_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .title_holder h3:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sa_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'sa_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'extendable',

            ]
        );
		$this->add_control(
			'sa_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_alpha .title_holder .in > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_alpha .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sa_read_more_types!' => 'none',
								],
				'default' => '#fff',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/**************************** SLIDER BETA ******************************/
		/**********************************************************************/
		$this->start_controls_section(
			'slider_beta_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('slider_b')
								]
			]
		);
		$this->add_control(
			'sb_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'sb_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'sb_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['sb_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
            'sb_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		$this->add_control(
			'sb_numbered_nav_color',
			[
				'label' => __( 'Numbered Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .swiper-slide.fn-numbered-pagination span.number' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .swiper-slide.fn-numbered-pagination span.line:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sb_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_slider_beta[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_slider_beta[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_slider_beta[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sb_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.6)',
			]
		);
		$this->add_control(
			'sb_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'sb_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sb_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_beta .item .title_holder p',
				'condition' => [
								'sb_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'sb_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sb_category_show' => 'yes'
								],
				'default' => '#d18750',
			]
		);
		$this->add_control(
			'sb_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sb_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_beta .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'sb_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sb_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .title_holder h3:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sb_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'sb_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'transform',

            ]
        );
		$this->add_control(
			'sb_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_beta .title_holder .in > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_beta .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sb_read_more_types!' => 'none',
								],
				'default' => '#d18750',
			]
		);
		$this->end_controls_section();
		
		/************************************************************************/
		/**************************** SLIDER DELTA *****************************/
		/**********************************************************************/
		$this->start_controls_section(
			'slider_delta_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('slider_d')
								]
			]
		);
		$this->add_control(
			'sd_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'sd_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'sd_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['sd_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
            'sd_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		$this->add_control(
			'sd_numbered_nav_color',
			[
				'label' => __( 'Numbered Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .swiper-slide.fn-numbered-pagination span.number' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .swiper-slide.fn-numbered-pagination span.line:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sd_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_slider_delta[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_slider_delta[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_slider_delta[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sd_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.6)',
			]
		);
		$this->add_control(
			'sd_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'sd_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sd_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_delta .item .title_holder p',
				'condition' => [
								'sd_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'sd_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sd_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sd_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sd_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_delta .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'sd_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sd_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .title_holder h3:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sd_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		
		$this->add_control(
			'sd_read_more_bgcolor',
			[
				'label' => __( 'Read More Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .title_holder a.open_post' => 'background-color: {{VALUE}};',
				],
				'default' => '#df3838',
			]
		);
		
		$this->add_control(
			'sd_read_more_color',
			[
				'label' => __( 'Read More Arrow Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_delta .title_holder a.open_post .a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_delta .title_holder a.open_post .b' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/**************************** SLIDER EPSILON ***************************/
		/**********************************************************************/
		$this->start_controls_section(
			'slider_epsilon_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('slider_e')
								]
			]
		);
		$this->add_control(
			'se_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'se_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'se_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['se_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
            'se_title_holder_gradient',
            [
                'label' => esc_html__( 'Title Holder Skin', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'black' 			=> esc_html__( 'Black', 'projectify' ),
                    'white' 			=> esc_html__( 'White', 'projectify' ),
                ],
                'default' => 'white',

            ]
        );
		$this->add_control(
            'se_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		$this->add_control(
			'se_numbered_nav_color',
			[
				'label' => __( 'Numbered Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .swiper-slide.fn-numbered-pagination span.number' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .swiper-slide.fn-numbered-pagination span.line:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'se_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_slider_epsilon[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_slider_epsilon[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_slider_epsilon[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'se_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.9)',
			]
		);
		$this->add_control(
			'se_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'se_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'se_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_epsilon .item .title_holder p',
				'condition' => [
								'se_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'se_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'se_category_show' => 'yes'
								],
				'default' => '#0b0464',
			]
		);
		$this->add_control(
			'se_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'se_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_epsilon .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'se_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#333',
			]
		);
		
		$this->add_control(
			'se_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder h3:hover' => 'color: {{VALUE}};',
				],
				'default' => '#000',
			]
		);
		$this->add_control(
			'se_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'se_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'transform',

            ]
        );
		$this->add_control(
			'se_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder .in > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_epsilon .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'se_read_more_types!' => 'none',
								],
				'default' => '#0b0464',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/**************************** SLIDER GAMMA *****************************/
		/**********************************************************************/
		$this->start_controls_section(
			'slider_gamma_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('slider_g')
								]
			]
		);
		$this->add_control(
			'sg_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'sg_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'sg_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['sg_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
            'sg_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		$this->add_control(
			'sg_numbered_nav_color',
			[
				'label' => __( 'Numbered Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .swiper-slide.fn-numbered-pagination span.number' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .swiper-slide.fn-numbered-pagination span.line:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sg_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_slider_gamma[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_slider_gamma[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_slider_gamma[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sg_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.6)',
			]
		);
		$this->add_control(
			'sg_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'sg_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sg_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_gamma .item .title_holder p',
				'condition' => [
								'sg_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'sg_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sg_category_show' => 'yes'
								],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sg_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sg_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_gamma .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'sg_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sg_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .title_holder h3:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sg_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'sg_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'extendable',

            ]
        );
		$this->add_control(
			'sg_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_gamma .title_holder .in > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_gamma .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sg_read_more_types!' => 'none',
								],
				'default' => '#870724',
			]
		);
		
		$this->end_controls_section();
		
		/************************************************************************/
		/**************************** SLIDER ZETA *****************************/
		/**********************************************************************/
		$this->start_controls_section(
			'slider_zeta_design',
			[
				'label' => __( 'Design', 'projectify' ),
				'condition' => [
								'fn_widget_layout' => array('slider_z')
								]
			]
		);
		$this->add_control(
			'sz_main_style',
			[
				'label' => __( 'Main Styles', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'sz_autoplay_switch',
            [
                'label' => esc_html__( 'Autoplay', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enabled' 				=> esc_html__( 'Enabled', 'projectify' ),
                    'disabled' 				=> esc_html__( 'Disabled', 'projectify' ),
                ],
                'default' => 'disabled',

            ]
        );
		$this->add_control(
			 'sz_autoplay_time',
			  [
				 'label'   => __( 'Autoplay Time in Milliseconds', 'projectify' ),
				 'type'    => Controls_Manager::NUMBER,
				 'default' => 5000,
				 'min'     => 500,
				 'max'     => 20000,
				 'step'    => 50,
				'condition' => ['sz_autoplay_switch' => 'enabled']
			  ]
		);
		$this->add_control(
            'sz_nav_types',
            [
                'label' => esc_html__( 'Navigation Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'round' 			=> esc_html__( 'Round', 'projectify' ),
                    'square' 			=> esc_html__( 'Square', 'projectify' ),
                ],
                'default' => 'round',

            ]
        );
		$this->add_control(
			'sz_numbered_nav_color',
			[
				'label' => __( 'Numbered Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .swiper-slide.fn-numbered-pagination span.number' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .swiper-slide.fn-numbered-pagination span.line:after' => 'background-color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		
		$this->add_control(
			'sz_nav_color',
			[
				'label' => __( 'Navigation Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .owl_control span.a' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .owl_control span.b' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .owl_control > div:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .owl_control > div > span:hover:after' => 'border-top-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .owl_control > div > span:hover:before' => 'border-top-color: {{VALUE}};border-right-color: {{VALUE}};border-bottom-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta[data-nav-types="square"] .owl_control > div > span:before, {{WRAPPER}} .projectify_slider_zeta[data-nav-types="square"] .owl_control > div > span:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} .projectify_slider_zeta[data-nav-types="square"] .owl_control > div > span .c:before, {{WRAPPER}} .projectify_slider_zeta[data-nav-types="square"] .owl_control > div > span .c:after' => 'background: {{VALUE}}',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sz_nav_bg_color',
			[
				'label' => __( 'Navigation Background Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .owl_control > div' => 'background-color: {{VALUE}};',
				],
				'default' => 'rgba(0,0,0,.5)',
			]
		);
		$this->add_control(
			'sz_category_style',
			[
				'label' => __( 'Category Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'sz_category_show',
			[
				'label' => __( 'Category Show', 'projectify' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' 	=> __( 'Show', 'projectify' ),
				'label_off' => __( 'Hide', 'projectify' ),
				'return_value' => 'yes',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sz_typography_2',
				'label' => __( 'Category Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_zeta .item .title_holder p',
				'condition' => [
								'sz_category_show' => 'yes'
								]
			]
		);
		$this->add_control(
			'sz_category_color',
			[
				'label' => __( 'Category Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .title_holder p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .title_holder p a:hover' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sz_category_show' => 'yes'
								],
				'default' => '#33703d',
			]
		);
		$this->add_control(
			'sz_title_style',
			[
				'label' => __( 'Title Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sz_typography_3',
				'label' => __( 'Title Typography', 'projectify' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .projectify_slider_zeta .title_holder h3 a',
			]
		);
		
		$this->add_control(
			'sz_title_color',
			[
				'label' => __( 'Title Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .title_holder h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .title_holder h3 a' => 'color: {{VALUE}};',
				],
				'default' => '#ccc',
			]
		);
		
		$this->add_control(
			'sz_title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .title_holder h3:hover a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .title_holder h3:hover' => 'color: {{VALUE}};',
				],
				'default' => '#fff',
			]
		);
		$this->add_control(
			'sz_read_more_style',
			[
				'label' => __( 'Read More Style', 'projectify' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
            'sz_read_more_types',
            [
                'label' => esc_html__( 'Link Types', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' 				=> esc_html__( 'None', 'projectify' ),
                    'extendable' 		=> esc_html__( 'Extendable', 'projectify' ),
                    'transform' 		=> esc_html__( 'Transform', 'projectify' ),
                    'static' 			=> esc_html__( 'Static', 'projectify' ),
                ],
                'default' => 'static',

            ]
        );
		$this->add_control(
			'sz_read_more_color',
			[
				'label' => __( 'Read More Color', 'projectify' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Color::get_type(),
					'value' => Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .projectify_slider_zeta .title_holder .in > span a' => 'color: {{VALUE}};border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .title_holder a.read_more:after' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .title_holder a.read_more .arrow:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projectify_slider_zeta .title_holder a.read_more .arrow:after' => 'border-bottom-color: {{VALUE}};',
				],
				'condition' => [
								'sz_read_more_types!' => 'none',
								],
				'default' => '#ccc',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'pjfy_lightbox_s',
			[
				'label' => __( 'Lightbox', 'projectify' ),
				'condition' => [
								'fn_widget_layout!' => 'list_just'
								]
			]
		);
		
		$this->add_control(
            'pjfy_lightbox',
            [
                'label' => esc_html__( 'Lightbox to Images', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'enable' 			=> esc_html__( 'Enable', 'projectify' ),
                    'disable' 			=> esc_html__( 'Disable', 'projectify' ),
                ],
                'default' => 'disable',

            ]
        );
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'translation',
			[
				'label' => __( 'Translation', 'projectify' ),
			]
		);
		
		$this->add_control(
            'lang_switcher',
            [
                'label' => esc_html__( 'Translation / Custom', 'projectify' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'translation' 		=> esc_html__( 'Translation', 'projectify' ),
                    'custom' 			=> esc_html__( 'Custom', 'projectify' ),
                ],
                'default' => 'translation',

            ]
        );
		
		$this->add_control(
		  'text__read_more',
		  [
			 'label'   		=> __( 'Read More', 'projectify' ),
			 'type'    		=> Controls_Manager::TEXTAREA,
			 'condition' 	=> ['lang_switcher' => 'custom'],
		  ]
		);
		
		$this->end_controls_section();
	}




	protected function render() {
		$settings 	= $this->get_settings();
		$post_types = $settings['fn_post_types'];
		$post_tax 	= Projectify_Helper::post_taxanomy($post_types);
		$post_tax 	= implode(',' , $post_tax);
		
		$post_terms = '';
		if(!empty($settings[$post_types.'_terms'])){
			$post_terms = $settings[$post_types.'_terms'];
		}
		if(!empty($post_terms)){$post_terms = implode(',' , $post_terms);}
		
		
		// since v1.3
		$included_posts = '';
		if(!empty($settings[$post_types.'_included_posts'])){
			$included_posts = $settings[$post_types.'_included_posts'];
		}
		if(!empty($included_posts)){$included_posts = implode(',' , $included_posts);}
		
		
		// FILTERS
		$post_number 				= $settings['fn_post_number']['size'];
		$post_offset 				= $settings['fn_post_offset'];
		$post_order 				= $settings['fn_post_order'];
		$post_orderby 				= $settings['fn_post_orderby'];
		$fn_widget_layout 			= $settings['fn_widget_layout'];
		if($post_orderby === 'select'){
			$post_orderby 	= '';
		}
		
		
		// LIGHTBOX
		$pjfy_lightbox				= $settings['pjfy_lightbox'];
		
		// since 04.08.2018
		$fn_page_include			= $settings['fn_page_include'];
		
		// since 28.07.2022
		$lang_switcher				= $settings['lang_switcher'];
		$text__read_more			= $settings['text__read_more'];
		
		
		if($fn_widget_layout === 'carousel_circle'){
			$cc_category_show 			= $settings['cc_category_show'];
			$cc_main_layout				= $settings['cc_main_layout'];
			$cc_box_shadow_gamma		= $settings['cc_box_shadow_gamma'];
			$cc_box_shadow_numbered		= $settings['cc_box_shadow_numbered'];
			$cc_box_shadow_numbered2	= $settings['cc_box_shadow_numbered2'];
			$cc_beta_bg_line			= $settings['cc_beta_bg_line'];
			$cc_numbered_img_thumb		= $settings['cc_numbered_img_thumb'];
			$cc_numbered_hover_thumb	= $settings['cc_numbered_hover_thumb'];
			
			$html = do_shortcode('[pjfy_carousel_circle included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" cc_category_show="'.$cc_category_show.'" cc_main_layout="'.$cc_main_layout.'" cc_box_shadow_gamma="'.$cc_box_shadow_gamma.'" cc_box_shadow_numbered="'.$cc_box_shadow_numbered.'" cc_box_shadow_numbered2="'.$cc_box_shadow_numbered2.'" cc_beta_bg_line="'.$cc_beta_bg_line.'" cc_numbered_img_thumb="'.$cc_numbered_img_thumb.'" cc_numbered_hover_thumb="'.$cc_numbered_hover_thumb.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'carousel_full_a'){
			$cfa_category_show 		= $settings['cfa_category_show'];
			$cfa_link_types 		= $settings['cfa_read_more_types'];
			$cfa_nav_types 			= $settings['cfa_nav_types'];
			$cfa_title_holder_type 	= $settings['cfa_title_holder_type'];
			$cfa_columns_number 	= $settings['cfa_columns_number']['size'];
			$cfa_autoplay_switch	= $settings['cfa_autoplay_switch'];
			$cfa_autoplay_time 		= $settings['cfa_autoplay_time'];

			$html = do_shortcode('[pjfy_carousel_full_alpha included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" cfa_category_show="'.$cfa_category_show.'" cfa_link_types="'.$cfa_link_types.'" cfa_nav_types="'.$cfa_nav_types.'" cfa_title_holder_type="'.$cfa_title_holder_type.'" cfa_columns_number="'.$cfa_columns_number.'" cfa_autoplay_switch="'.$cfa_autoplay_switch.'" cfa_autoplay_time="'.$cfa_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}else if($fn_widget_layout === 'carousel_full_b'){
			$cfb_category_show 			= $settings['cfb_category_show'];
			$cfb_nav_types 				= $settings['cfb_nav_types'];
			$cfb_title_holder_type 		= $settings['cfb_title_holder_type'];
			$cfb_title_holder_position 	= $settings['cfb_title_holder_position'];
			$cfb_columns_number 		= $settings['cfb_columns_number']['size'];
			$cfb_autoplay_switch		= $settings['cfb_autoplay_switch'];
			$cfb_autoplay_time 			= $settings['cfb_autoplay_time'];

			$html = do_shortcode('[pjfy_carousel_full_beta included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" cfb_category_show="'.$cfb_category_show.'" cfb_nav_types="'.$cfb_nav_types.'" cfb_title_holder_type="'.$cfb_title_holder_type.'" cfb_title_holder_position="'.$cfb_title_holder_position.'" cfb_columns_number="'.$cfb_columns_number.'" cfb_autoplay_switch="'.$cfb_autoplay_switch.'" cfb_autoplay_time="'.$cfb_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'carousel_full_i'){
			$cfi_category_show 		= $settings['cfi_category_show'];
			$cfi_link_types 		= $settings['cfi_read_more_types'];
			$cfi_nav_types 			= $settings['cfi_nav_types'];
			$cfi_title_holder_type 	= $settings['cfi_title_holder_type'];
			$cfi_columns_number 	= $settings['cfi_columns_number']['size'];

			$html = do_shortcode('[pjfy_carousel_full_interactive included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" cfi_category_show="'.$cfi_category_show.'" cfi_link_types="'.$cfi_link_types.'" cfi_nav_types="'.$cfi_nav_types.'" cfi_title_holder_type="'.$cfi_title_holder_type.'" cfi_columns_number="'.$cfi_columns_number.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}else if($fn_widget_layout === 'carousel_square'){
			$cs_category_show 		= $settings['cs_category_show'];
			$cs_nav_types 			= $settings['cs_nav_types'];
			$cs_main_layout			= $settings['cs_main_layout'];
			$cs_box_shadow_alpha	= $settings['cs_box_shadow_alpha'];
			$cs_box_shadow_beta		= $settings['cs_box_shadow_beta'];
			$cs_item_ratio			= $settings['cs_item_ratio'];

			$html = do_shortcode('[pjfy_carousel_square included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" cs_category_show="'.$cs_category_show.'" cs_nav_types="'.$cs_nav_types.'" cs_main_layout="'.$cs_main_layout.'" cs_box_shadow_alpha="'.$cs_box_shadow_alpha.'" cs_box_shadow_beta="'.$cs_box_shadow_beta.'" cs_item_ratio="'.$cs_item_ratio.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'carousel_with_c'){
			$cwc_category_show 			= $settings['cwc_category_show'];
			$cwc_main_layout			= $settings['cwc_main_layout'];
			$cwc_img_ratio				= $settings['cwc_img_ratio'];
			$cwc_fslide_title			= $settings['cwc_fslide_title'];
			$cwc_fslide_desc			= $settings['cwc_fslide_desc'];
			$cwc_fslide_sign			= $settings['cwc_fslide_sign']['url'];
			$cwc_alpha_bg_type			= $settings['cwc_alpha_bg_type'];

			$html = do_shortcode('[pjfy_carousel_with_content included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" cwc_category_show="'.$cwc_category_show.'" cwc_main_layout="'.$cwc_main_layout.'" cwc_img_ratio="'.$cwc_img_ratio.'" cwc_fslide_title="'.$cwc_fslide_title.'" cwc_fslide_desc="'.$cwc_fslide_desc.'" cwc_fslide_sign="'.$cwc_fslide_sign.'" cwc_alpha_bg_type="'.$cwc_alpha_bg_type.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'list_just'){
			$lj_category_show 			= $settings['lj_category_show'];
			$lj_img_height				= $settings['lj_img_height']['size'];
			$lj_img_gutter				= $settings['lj_img_gutter']['size'];

			$html = do_shortcode('[pjfy_list_justified included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" lj_category_show="'.$lj_category_show.'" lj_img_height="'.$lj_img_height.'" lj_img_gutter="'.$lj_img_gutter.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'list_masonry'){
			$lm_category_show 			= $settings['lm_category_show'];
			$lm_main_layout				= $settings['lm_main_layout'];
			$lm_cols_number				= $settings['lm_cols_number']['size'];
			$lm_term_filter				= $settings['lm_term_filter'];
			$lm_title_holder_pos		= $settings['lm_title_holder_pos'];
			$lm_title_holder_bg			= $settings['lm_title_holder_bg'];
			$lm_title_holder_animation	= $settings['lm_title_holder_animation'];
			$lm_grid_ratio				= $settings['lm_grid_ratio'];

			$html = do_shortcode('[pjfy_list_masonry included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" lm_category_show="'.$lm_category_show.'" lm_main_layout="'.$lm_main_layout.'" lm_cols_number="'.$lm_cols_number.'" lm_term_filter="'.$lm_term_filter.'" lm_title_holder_bg="'.$lm_title_holder_bg.'" lm_title_holder_pos="'.$lm_title_holder_pos.'" lm_title_holder_animation="'.$lm_title_holder_animation.'" lm_grid_ratio="'.$lm_grid_ratio.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'slider_a'){
			$sa_category_show 		= $settings['sa_category_show'];
			$sa_link_types 			= $settings['sa_read_more_types'];
			$sa_nav_types 			= $settings['sa_nav_types'];
			$sa_autoplay_switch		= $settings['sa_autoplay_switch'];
			$sa_autoplay_time 		= $settings['sa_autoplay_time'];

			$html = do_shortcode('[pjfy_slider_alpha included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" sa_category_show="'.$sa_category_show.'" sa_link_types="'.$sa_link_types.'" sa_nav_types="'.$sa_nav_types.'" sa_autoplay_switch="'.$sa_autoplay_switch.'" sa_autoplay_time="'.$sa_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}else if($fn_widget_layout === 'slider_b'){
			$sb_category_show 		= $settings['sb_category_show'];
			$sb_link_types 			= $settings['sb_read_more_types'];
			$sb_nav_types 			= $settings['sb_nav_types'];
			$sb_autoplay_switch		= $settings['sb_autoplay_switch'];
			$sb_autoplay_time 		= $settings['sb_autoplay_time'];

			$html = do_shortcode('[pjfy_slider_beta included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" sb_category_show="'.$sb_category_show.'" sb_link_types="'.$sb_link_types.'" sb_nav_types="'.$sb_nav_types.'" sb_autoplay_switch="'.$sb_autoplay_switch.'" sb_autoplay_time="'.$sb_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}else if($fn_widget_layout === 'slider_d'){
			$sd_category_show 		= $settings['sd_category_show'];
			$sd_nav_types 			= $settings['sd_nav_types'];
			$sd_autoplay_switch	= $settings['sd_autoplay_switch'];
			$sd_autoplay_time 		= $settings['sd_autoplay_time'];

			$html = do_shortcode('[pjfy_slider_delta included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" sd_category_show="'.$sd_category_show.'" sd_nav_types="'.$sd_nav_types.'" sd_autoplay_switch="'.$sd_autoplay_switch.'" sd_autoplay_time="'.$sd_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'"]');
			echo $html;
		}else if($fn_widget_layout === 'slider_e'){
			$se_category_show 			= $settings['se_category_show'];
			$se_link_types 				= $settings['se_read_more_types'];
			$se_nav_types 				= $settings['se_nav_types'];
			$se_title_holder_gradient 	= $settings['se_title_holder_gradient'];
			$se_autoplay_switch			= $settings['se_autoplay_switch'];
			$se_autoplay_time 			= $settings['se_autoplay_time'];

			$html = do_shortcode('[pjfy_slider_epsilon included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" se_category_show="'.$se_category_show.'" se_link_types="'.$se_link_types.'" se_nav_types="'.$se_nav_types.'" se_title_holder_gradient="'.$se_title_holder_gradient.'" se_autoplay_switch="'.$se_autoplay_switch.'" se_autoplay_time="'.$se_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}else if($fn_widget_layout === 'slider_g'){
			$sg_category_show 		= $settings['sg_category_show'];
			$sg_link_types 			= $settings['sg_read_more_types'];
			$sg_nav_types 			= $settings['sg_nav_types'];
			$sg_autoplay_switch		= $settings['sg_autoplay_switch'];
			$sg_autoplay_time 		= $settings['sg_autoplay_time'];

			$html = do_shortcode('[pjfy_slider_gamma included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" sg_category_show="'.$sg_category_show.'" sg_link_types="'.$sg_link_types.'" sg_nav_types="'.$sg_nav_types.'" sg_autoplay_switch="'.$sg_autoplay_switch.'" sg_autoplay_time="'.$sg_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}else if($fn_widget_layout === 'slider_z'){
			$sz_category_show 		= $settings['sz_category_show'];
			$sz_link_types 			= $settings['sz_read_more_types'];
			$sz_nav_types 			= $settings['sz_nav_types'];
			$sz_autoplay_switch		= $settings['sz_autoplay_switch'];
			$sz_autoplay_time 		= $settings['sz_autoplay_time'];

			$html = do_shortcode('[pjfy_slider_zeta included_posts="'.$included_posts.'" post_type="'.$post_types.'" post_tax="'.$post_tax.'" post_terms="'.$post_terms.'" post_number="'.$post_number.'" post_offset="'.$post_offset.'" post_order="'.$post_order.'" post_orderby="'.$post_orderby.'" sz_category_show="'.$sz_category_show.'" sz_link_types="'.$sz_link_types.'" sz_nav_types="'.$sz_nav_types.'" sz_autoplay_switch="'.$sz_autoplay_switch.'" sz_autoplay_time="'.$sz_autoplay_time.'" pjfy_lightbox="'.$pjfy_lightbox.'" fn_page_include="'.$fn_page_include.'" lang_switcher="'.$lang_switcher.'" text__read_more="'.$text__read_more.'"]');
			echo $html;
		}
		
	}

}
